@@ -111,20 +111,43 @@ def get_df_notas(anio):
     return df_notas
 
 
-def get_df_servicios(macro_region=None,region=None,anio=None):
+def get_df_servicios(macro_region=None,region=None,anio=None,totales=False):
     print("Imprimiendo el anio servicio ",anio)
+    
+    anio_min = 2016
+    if (anio is not None and anio<anio_min):
+        raise Exception("No existe data de servicios menor que {}".format(anio_min))
+    
     if anio is None:
         print("Extrayendo servicios general")
         url =   get_path_BD() + "\\03.Servicios\\_data_\\Padron_web.dbf"        
         dbf_ser = Dbf5(url , codec='ISO-8859-1')
         df_servicios = dbf_ser.to_dataframe()
-    elif anio==2021:
-        print("Extrayendo servicios 2021")
-        url =   get_path_BD() + "\\03.Servicios\\_data_\\Padron_web_2021.dta"        
-        df_servicios = pd.read_stata(url)   
+        
+    elif anio<=2020:
+        url =   get_path_BD()+"\\03.Servicios\\_data_\\Padron_web_{}.dbf".format(anio)        
+        dbf_ser = Dbf5(url , codec='ISO-8859-1')
+        df_servicios = dbf_ser.to_dataframe()
+        if anio==2016:
+            df_codii_dre =  pd.read_csv(get_path_BD() + "\\03.Servicios\\_data_\\CODOOII_D_REGION.csv",dtype={'CODOOII': str})
+            df_servicios = pd.merge(df_servicios,df_codii_dre,left_on="CODOOII",right_on="CODOOII",how="inner")
+            df_servicios.rename(columns={'D_AREASIG': 'DAREACENSO'}, inplace=True)       
+        
+    elif anio==2021:        
+                
+        url =   get_path_BD() + "\\03.Servicios\\_data_\\Padron_web_2021.dbf"        
+        dbf_ser = Dbf5(url , codec='ISO-8859-1')
+        df_servicios = dbf_ser.to_dataframe()
         df_servicios.columns = map(lambda x: str(x).upper(), df_servicios.columns)
+        #url =   get_path_BD() + "\\03.Servicios\\_data_\\Padron_web_2021.dta"        
+        #df_servicios = pd.read_stata(url)   
+        #df_servicios.columns = map(lambda x: str(x).upper(), df_servicios.columns)
+        
+    cls = ["COD_MOD","ANEXO","CODGEO","GESTION","DAREACENSO",'D_TIPSSEXO','D_REGION']
+    if totales:
+        cls = cls + ['TALUM_HOM','TALUM_MUJ','TALUMNO', 'TDOCENTE', 'TSECCION']
     
-    df_servicios = df_servicios[["COD_MOD","ANEXO","CODGEO","GESTION","DAREACENSO",'D_TIPSSEXO','D_REGION']].copy() 
+    df_servicios = df_servicios[cls].copy() 
     df_servicios["ANEXO"] =df_servicios['ANEXO'].astype("int8")
     df_servicios["GESTION"] =df_servicios['GESTION'].astype("int8")    
 
@@ -210,11 +233,21 @@ def get_path_BD():
     path_file =hg.get_base_path()+"\\src\\Prj_BD"
     return path_file
 
-{'COD_MOD':str,'ANEXO':int}
+
 
 def get_siagie_por_anio(anio,id_grado=None,modalidad='EBR',dtypes_columns={'ID_PERSONA':int,'COD_MOD':str,'ANEXO':int},
                         columns_n= ['ID_PERSONA','ID_GRADO','ID_NIVEL','COD_MOD','ANEXO'],
-                        id_persona_df=None,id_nivel=None,id_nivel_list=None,reduce_mem_usage=False):       
+                        id_persona_df=None,id_nivel=None,id_nivel_list=None,reduce_mem_usage=False):  
+
+    id_niveles_inicial_ebr = ['A1','A2','A3','A5']
+    if id_nivel  is not None:
+        if id_nivel=="A0":      
+            print("El nivel ficticio A0  sera reemplazado por los verdaderos niveles ",id_niveles_inicial_ebr)
+            
+    if id_nivel_list  is not None:
+        if "A0" in id_nivel_list:    
+            print("El nivel ficticio A0  sera reemplazado por los verdaderos niveles ",id_niveles_inicial_ebr)
+     
 
     path_file = get_path_BD_siagie_procesado()
     if (modalidad=='EBR'):    
@@ -224,17 +257,18 @@ def get_siagie_por_anio(anio,id_grado=None,modalidad='EBR',dtypes_columns={'ID_P
                                   dtype=dtypes_columns,iterator=True, chunksize=500000)
             
 
-            df = procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list)
+            df = procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list,id_niveles_inicial_ebr)
         else:
             list_df = []
             for nivel in ["A0","B0","F0"]:               
-
+                
                 url = path_file+"\\NOMINAL_{}_{}.csv"
                 iter_pd = pd.read_csv(url.format(nivel,anio), usecols=columns_n,encoding="latin-1",
                                       sep="|",dtype=dtypes_columns,iterator=True, chunksize=500000)
                 
-                df = procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list)
+                df = procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list,id_niveles_inicial_ebr)
                 list_df.append(df)
+                
             df = pd.concat(list_df)
             
     elif(modalidad=='EBE'):
@@ -249,14 +283,21 @@ def get_siagie_por_anio(anio,id_grado=None,modalidad='EBR',dtypes_columns={'ID_P
         return df
 
 
-def procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list):
+def procesar_chunk_siagie(iter_pd,id_grado,id_persona_df,id_nivel,id_nivel_list,id_niveles_inicial_ebr):
     chunk_list = []
+
     for chunk in iter_pd:
         if id_grado  is not None:
             chunk = chunk[(chunk['ID_GRADO'] == id_grado)] 
         if id_nivel  is not None:
-            chunk = chunk[(chunk['ID_NIVEL'] == id_nivel)]  
+            if id_nivel=="A0":     
+                chunk = chunk[(chunk['ID_NIVEL'].isin(id_niveles_inicial_ebr))] 
+            else:                  
+                chunk = chunk[(chunk['ID_NIVEL'] == id_nivel)]  
         if id_nivel_list  is not None:
+            if "A0" in id_nivel_list:    
+                id_nivel_list.remove( "A0")                
+                id_nivel_list = id_nivel_list + id_niveles_inicial_ebr                
             chunk = chunk[(chunk['ID_NIVEL'].isin(id_nivel_list))]  
         if id_persona_df is not None:
             #print(id_persona_df.shape)
