@@ -11,12 +11,14 @@ import json
 import os
 import math
 import sys
-
+import math
+import os
 import pandas as pd
 import numpy as np
 import time
 from datetime import datetime
-
+import matplotlib.pyplot as plt
+import seaborn as sns
 #import core_helper.helper_plot as hp
 import src.Prj_Core.core_helper.helper_plot as hp
 
@@ -31,25 +33,44 @@ import src.Prj_Core.core_helper.model.custom_bagging__lgb_model as cb_lgb_model
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy, X_train=None,y_train=None,X_test=None,y_test=None,url=None):
+def modelar_clasificacion_binaria(strategy, X_train=None,y_train=None,X_test=None,y_test=None,params=None,url=None,print_consola=True):
     start = time.time()
     if (strategy=="neg_bagging_fraction__lgb_model"):
-        model , predicted_probas   = nbf_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
+        model , predicted_probas   = nbf_lgb_model.modelar(X_train,y_train,X_test,y_test,params,url)
     if (strategy=="scale_pos_weight__lgb_model"):
-        model , predicted_probas   = spw_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
+        model , predicted_probas   = spw_lgb_model.modelar(X_train,y_train,X_test,y_test,params,url)
     if (strategy=="custom_bagging__lgb_model"):
         model , predicted_probas   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
 
-    kpis = generar_reporte(model,predicted_probas,X_test,y_test,url)
+    kpis = generar_reporte(model,predicted_probas,X_test,y_test,url,print_consola)
     print("Time elapsed: ", time.time() - start)
     
     return model , predicted_probas  , kpis
+
+
+def modelar_clasificacion_binaria_rscv(strategy, X_train,y_train=None,X_test=None,y_test=None,score_rs=None,params=None,param_dist=None, n_iter=None,n_jobs=None,url=None,print_consola=True):
+    if url is not None:
+        hg.validar_directorio(url)     
+
+    if (strategy=="neg_bagging_fraction__lgb_model"):
+        results, model , predicted_probas, params, best_params = nbf_lgb_model.modelar_rscv(X_train,y_train,X_test,y_test,score_rs,params,param_dist,n_iter,n_jobs,url)
+        
+    if (strategy=="scale_pos_weight__lgb_model"):
+        results, model , predicted_probas, params, best_params = spw_lgb_model.modelar_rscv(X_train,y_train,X_test,y_test,score_rs,params,param_dist,n_iter,n_jobs,url)
+       
+    if (strategy=="custom_bagging__lgb_model"):
+        results, model , predicted_probas, params, best_params = spw_lgb_model.modelar_rscv(X_train,y_train,X_test,y_test,score_rs,params,param_dist,n_iter,n_jobs,url)
+       
+    kpis = generar_reporte(model,predicted_probas,X_test,y_test,url,print_consola)
+    
+    return results, model , predicted_probas, params, best_params ,kpis
     
 
-def generar_reporte(model,predicted_probas, X_test, y_test,url):    
-    kpis = hp.print_kpis_rendimiento_modelo(y_test,predicted_probas,url)   
+def generar_reporte(model,predicted_probas, X_test, y_test,url,print_consola):    
+    kpis = hp.print_kpis_rendimiento_modelo(y_test,predicted_probas,url,print_consola)   
     if  isinstance(model, list)==False:
-        hp.print_shap_plot(model, X_test, url)      
+        if (print_consola):
+            hp.print_shap_plot(model, X_test, url)      
     g.generate_summary_evaluation(X_test,predicted_probas,y_test,url) 
     return kpis
     
@@ -86,10 +107,10 @@ def get_result_df(KPIs_list):
 
     return df
 
-def get_kpi_df_nacional(PATH_RESULT="resultado",grupos_grados=None):
+def get_kpi_df_nacional(PATH_RESULT="resultado",grupos_grados=None,lista_mr=None):
     df_resumen = None
-    grupos_grados = {"1 prim": [4],"2 prim": [5], "3-5 prim": [6,7,8], "6 prim": [9], "1-4 sec": [10,11,12,13],"5 sec": [14]}
-    lista_mr = ["centro","norte","sur","oriente","lima"]
+    #grupos_grados = {"1 prim": [4],"2 prim": [5], "3-5 prim": [6,7,8], "6 prim": [9], "1-4 sec": [10,11,12,13],"5 sec": [14]}
+    #lista_mr = ["centro","norte","sur","oriente","lima"]
     
     list_df = []
     for key, grupo_grado  in grupos_grados.items():
@@ -105,33 +126,62 @@ def get_kpi_df_nacional(PATH_RESULT="resultado",grupos_grados=None):
     return df_resumen
 
 
+def get_test_size(X_t):
+    Total_X_t =  X_t.shape[0]
+    Total_Test = 20000 # Cantidad minima de Test
+    test_size = round(Total_Test/Total_X_t,5)
+    
+    min_test_size = 0.25
+    if(test_size > min_test_size):
+        test_size = 0.25    
+    print("test_size : ", test_size)
+    return test_size
 
-def export_resultado_final_nacional(alto=0.75,medio=0.5,path="resultado"):
-    grupos_grados = {"1 prim": [4],"2 prim": [5], "3-5 prim": [6,7,8], "6 prim": [9], "1-4 sec": [10,11,12,13],"5 sec": [14]}
-    lista_mr = ["centro","norte","sur","oriente","lima"]
-    hg.validar_directorio(path)
-    PATH_RESULT = path
+def export_resultado_final_nacional(alto=0.75,medio=0.5,grupos_grados=None,lista_mr=None,path="resultado",
+                                    delta_path=None,modelos=[]):
+    if (grupos_grados is None):
+        msg = "ERROR: No se ha especificado el parametro 'grupos_grados'"      
+        raise Exception(msg)   
+        
+    if (lista_mr is None):
+        msg = "ERROR: No se ha especificado el parametro 'lista_mr', que contiene la lista de macro regiones"      
+        raise Exception(msg)   
+
+    hg.validar_directorio(path)    
+    if delta_path is not None:
+        hg.validar_directorio(delta_path) 
+        
     now = datetime.now()
     # dd/mm/YY H:M:S
     dt_string = now.strftime("%d%m%Y_%H%M%S")
     #"norte","sur"
     #grupos_grados = { "3-5 prim": [6,7,8]}
     #lista_mr = ["norte"]
-    df_resumen = get_kpi_df_nacional(PATH_RESULT,grupos_grados)
+    df_resumen = get_kpi_df_nacional(path+"/02.Modelo",grupos_grados)
         
     dt = {'COD_MOD':str,'COD_MOD_T':str,'ANEXO':int,'ANEXO_T':int,'EDAD':int,
       'N_DOC':str,'COD_MOD_T_MENOS_1':str,
       'ANEXO_T_MENOS_1':int,'NUMERO_DOCUMENTO_APOD':str,'ID_PERSONA':int}
     
     list_result = []
-    columns = ['ID_PERSONA','custom_bagging__lgb_model', 'scale_pos_weight__lgb_model', 'neg_bagging_fraction__lgb_model']
+    columns = ['ID_PERSONA'] + modelos
     
     for key, grupo_grado  in grupos_grados.items():
         
         for macro_region in lista_mr:
-            best_model = df_resumen[(df_resumen.key_grupo_grado==key) & (df_resumen['Macro Región']==macro_region)].Modelo.iloc[0]
+            #print("obteniendo best model : ",macro_region," - ",key)
+            best_model = df_resumen[(df_resumen.key_grupo_grado==key) & (df_resumen['Macro Región']==macro_region)]
+            if best_model.shape[0]==0:
+                msg = "ERROR: El archivo resultados.xlsx para el grupo de grados '"+key+"' no tiene resultados para la macro region: "+macro_region      
+                raise Exception(msg)   
+                
+            best_model = best_model.Modelo.iloc[0]
             print(best_model," - ",macro_region," - ",key)
-            specific_url = '{}/{}/{}/{}'.format(PATH_RESULT,key,macro_region,"X_t_mas_1.csv")
+            if delta_path is None:
+                specific_url = '{}/{}/{}/{}/{}'.format(path,"01.data_input",key,macro_region,"X_t_mas_1.csv")
+            else:
+                specific_url = '{}/{}/{}/{}/{}'.format(delta_path,"01.data_input",key,macro_region,"X_t_mas_1.csv")
+                
             df=pd.read_csv(specific_url,dtype=dt, encoding="utf-8",usecols=columns) 
             df['RISK_SCORE'] = df[best_model] 
             list_result.append(df)
@@ -148,12 +198,87 @@ def export_resultado_final_nacional(alto=0.75,medio=0.5,path="resultado"):
     
     cls_export = ["ID_PERSONA","RISK_SCORE",'PREDICCION']
     print("Total de registros : ",df_nacional.shape)
-    df_nacional[cls_export].to_stata("{}/nacional_{}.dta".format(PATH_RESULT,dt_string)) 
+    if delta_path is None:
+        url = "{}/{}/".format(path,"03.data_output")
+        hg.validar_directorio(url)  
+        filename = "nacional_{}.dta".format(dt_string)
+        df_nacional[cls_export].to_stata(url+filename) 
+    else:
+        url = "{}/{}/".format(delta_path,"02.data_output")
+        hg.validar_directorio(url) 
+        filename = "nacional_{}.dta".format(dt_string)         
+        df_nacional[cls_export].to_stata(url+filename)
     return df_nacional
 
 
 
 
+def show_barplot_resultado_final_nacional(grupos_grados=None, lista_mr = None, scores = [] ,path = None,show=False):
+    df_resumen = get_kpi_df_nacional(PATH_RESULT=path,grupos_grados=grupos_grados,lista_mr=lista_mr)
+    
+    list_result_total = []
+    for macro_region in lista_mr:
+        list_mr = []
+        for score in scores:
+            for key, grupo_grado  in grupos_grados.items():
+                directory = path+"/"+str(key)
+                hg.validar_directorio(directory) 
+                final_path = directory+ "/resultados.xlsx"
+                
+                df = pd.read_excel(final_path, index_col=0)  
+               
+                best_model = df_resumen[(df_resumen.key_grupo_grado==key) & (df_resumen['Macro Región']==macro_region)]
+                if best_model.shape[0]==0:
+                    msg = "ERROR: El archivo resultados.xlsx para el grupo de grados '"+key+"' no tiene resultados para la macro region: "+macro_region      
+                    raise Exception(msg)   
+    
+                valor = best_model[score].values[0]
+                
+                df_mr_grado = pd.DataFrame() 
+                df_mr_grado['Valor'] = [valor] 
+                df_mr_grado['Indicador'] = [score] 
+                df_mr_grado['Grados'] = [key]        
+                df_mr_grado['MR'] = [macro_region]
+    
+                list_mr.append(df_mr_grado)
+        df_mr = pd.concat(list_mr)
+        show_barplot_rf_n(df_mr,macro_region,path,show)
+        list_result_total.append(df_mr)
+    
+    df_result_total = pd.concat(list_result_total)
+    show_barplot_rf_n(df_result_total,"Nacional",path,show)
+
+def show_barplot_rf_n(df,titulo_top_left="",dir_name=None,show=False):
+    fig = plt.figure(figsize=(15, 6))
+    ax = sns.barplot(x='Grados',y='Valor',data=df, hue='Indicador')
+    
+    for p in ax.patches:    
+        height = p.get_height()
+        #print(height)
+        if math.isnan(height):
+            height = 0
+        #height = round(height,0)
+        ax.text(p.get_x()+p.get_width()/2.,
+                height ,
+                '{:0.2f}'.format(height),
+                ha="center") 
+    plt.suptitle(titulo_top_left.upper()+' - Robustez por Grado', fontsize=20)
+    ax.legend(ncol = 3, loc = 'best', bbox_to_anchor=(0.65, -0.1))
+    
+    
+    if show :
+        plt.show()
+       
+    filename =titulo_top_left+'_barplot.png'
+    if len(dir_name.strip())==0 :
+        full_dirname = filename
+    else:
+        if os.path.isdir(dir_name)==False:
+            os.makedirs(dir_name)
+        full_dirname = os.path.join(dir_name, filename)         
+            
+    plt.savefig(full_dirname, bbox_inches='tight')
+    plt.close()
 
 '''            
 def split_x_y(ID_GRADO,macro_region,modalidad="EBR"):
