@@ -37,7 +37,7 @@ def trim_category_cls(df,cl_list=[]):
 
 def fill_nan_with_nan_category_in_cls(df,cl_list):    
     for c_name in cl_list:
-        print("columna :: ",c_name)
+        print("fill_nan_with_nan_category: ",c_name)
         df[c_name].replace(np.nan, "NAN_CATEGORY" ,inplace=True)        
     return df
 
