@@ -84,6 +84,11 @@ def get_cat_columns(X):
     _categorical_columns_name = list(set(_cols) - set(_num_cols))
     return _categorical_columns_name
 
+def get_bool_columns(X):  
+    bool_cols = [col for col in X 
+                 if np.isin(X[col].dropna().unique(), [0, 1]).all()]
+    return bool_cols
+
 
 # Generate dataset with 1000 samples, 100 features and 2 classes
 def generate_dataset(n_samples=10000, n_features=100, n_classes=2, random_state=42,df=True):  
