@@ -85,10 +85,66 @@ def get_fn_eval(score_rs):
     return fn_eval
 
 
+def get_hypers_dic(url,common_params):  
+    hypers_dic = {}
+    dir_list = os.listdir(url)    
+    for file_name in dir_list:
+        name = os.path.splitext(file_name)[0]    
+        file_path  = url+file_name
+        print(file_path)
+        with open(file_path) as json_file:
+            data = json.load(json_file)    
+            for key_mr , value_mr in data.items():
+                for key_mr_model, value_mr_model in value_mr.items():
+                    data[key_mr][key_mr_model] = {**common_params, **value_mr_model }
+                    #data[key_mr][model_name] = {**common_params, **data[key_mr][model_name] }
+           
+            hypers_dic[name] = data  
+            
+    return hypers_dic
+
+
+def get_hypers_gr_mr_dic(hyperparameters_dir,key,macro_region,model_name,params):
+    
+    hypers_dic = get_hypers_dic(hyperparameters_dir, params)
+    
+    hypers_dic_gr = hypers_dic.get(key, None)
+    if hypers_dic_gr is None:
+        print("\nNo existe hyperparametros para {",key, "}, se empleara valores por defecto\n")
+        return params
+    else:
+        hypers_dic_gr_mr = hypers_dic_gr.get(macro_region, None)
+        if hypers_dic_gr_mr is None:
+            print("\nNo existe hyperparametros para {",key,"-",macro_region, "}, se empleara valores por defecto\n")
+            return params
+        else:
+            hypers_dic_gr_mr_model = hypers_dic_gr_mr.get(model_name, None)
+            if hypers_dic_gr_mr_model is None:
+                print("\nNo existe hyperparametros para {",key,"-",macro_region, "-",model_name,"}, se empleara valores por defecto\n")
+                return params
+            else:
+                return hypers_dic_gr_mr_model
+        
+def save_hyper_draft(best_params_full,kpis_dict_full,hyper_draft_dir,key):
+    save_json(best_params_full,hyper_draft_dir+key+".json") 
+    save_json(kpis_dict_full,hyper_draft_dir+key+"_kpi.json") 
  
 
+def save_json(dict_obj, url_file):
+    if url_file is None:
+        print("")
+    else:
+        # create json object from dictionary
+        json_ = json.dumps(dict_obj, sort_keys=True, indent=4)
+        # open file for writing, "w" 
+        f = open(url_file,"w")
+        # write json object to file
+        f.write(json_)
+        # close file
+        f.close() 
+
 def get_kfold():
-    n_splits = 10
+    n_splits = 4
     kfold = StratifiedKFold(n_splits=n_splits, shuffle=True,random_state=2)
     return kfold
 
@@ -113,6 +169,9 @@ def load_save_model(url_dir):
     return loaded_model
 
 
+
+
+
 def generate_summary_evaluation(X,predicted_probas,y,dir_name,modalidad="EBR"):
     
     if dir_name is None:
